@@ -233,7 +233,7 @@ network_device_update_essid (NetworkInterface *device)
         /* Query essid */
         memset (&iwr, 0, sizeof (struct iwreq));
         memset (essid, 0, IW_ESSID_MAX_SIZE + 1);
-        strncpy (iwr.ifr_name, device->name, IFNAMSIZ);
+        strncpy (iwr.ifr_name, device->name, IFNAMSIZ - 1);
         iwr.u.essid.pointer = (caddr_t) essid;
         iwr.u.essid.length = IW_ESSID_MAX_SIZE;
         ret = ioctl (device->manager->priv->fd, SIOCGIWESSID, &iwr);
@@ -328,12 +328,12 @@ network_device_up (NetworkInterface *device)
 static void
 network_device_down (NetworkInterface *device)
 {
-        if (!device->flags & NETWORK_INTERFACE_UP)
+        if (!(device->flags & NETWORK_INTERFACE_UP))
                 return;
 
         device->flags &= ~NETWORK_INTERFACE_UP;
 
-        if (device->contexts)
+        if (device->contexts != NULL)
                 g_hash_table_foreach (device->contexts,
                                       context_signal_down,
                                       device->manager);
