@@ -163,7 +163,10 @@ gupnp_service_proxy_action_unref (GUPnPServiceProxyAction *action)
         }
 }
 
-G_DEFINE_BOXED_TYPE (GUPnPServiceProxyAction, gupnp_service_proxy_action, gupnp_service_proxy_action_ref, gupnp_service_proxy_action_unref)
+G_DEFINE_BOXED_TYPE (GUPnPServiceProxyAction,
+                     gupnp_service_proxy_action,
+                     gupnp_service_proxy_action_ref,
+                     gupnp_service_proxy_action_unref)
 
 static void
 callback_data_free (CallbackData *data)
@@ -2246,6 +2249,8 @@ subscription_expire (gpointer user_data)
         /* Reset timeout ID */
         proxy->priv->subscription_timeout_src = NULL;
 
+        g_return_val_if_fail (proxy->priv->sid != NULL, FALSE);
+
         /* Send renewal message */
         context = gupnp_service_info_get_context (GUPNP_SERVICE_INFO (proxy));
 
@@ -2303,6 +2308,12 @@ subscribe_got_response (G_GNUC_UNUSED SoupSession *session,
         proxy->priv->pending_messages =
                 g_list_remove (proxy->priv->pending_messages, msg);
 
+        /* Remove subscription timeout */
+        if (proxy->priv->subscription_timeout_src) {
+                g_source_destroy (proxy->priv->subscription_timeout_src);
+                proxy->priv->subscription_timeout_src = NULL;
+        }
+
         /* Check whether the subscription is still wanted */
         if (!proxy->priv->subscribed)
                 return;
