@@ -837,6 +837,7 @@ new_action_response_str (const char   *action_name,
         g_string_append (str, "Response xmlns:u=");
 
         if (service_type != NULL) {
+                g_string_append_c (str, '"');
                 g_string_append (str, service_type);
                 g_string_append_c (str, '"');
         } else {
@@ -967,6 +968,9 @@ control_server_handler (SoupServer                      *server,
         *action_name = '\0';
         action_name += 1;
 
+        if (*soap_action == '"')
+                soap_action += 1;
+
         /* This memory is libsoup-owned so we can do this */
         end = strrchr (action_name, '"');
         if (end)
@@ -1001,7 +1005,7 @@ control_server_handler (SoupServer                      *server,
         action->doc            = gupnp_xml_doc_new(doc);
         action->node           = action_node;
         action->response_str   = new_action_response_str (action_name,
-                                                        soap_action);
+                                                          soap_action);
         action->context        = g_object_ref (context);
         action->argument_count = 0;
 
